==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/ResourceFieldSelectorFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ResourceFieldSelectorFluentImpl<A extends io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent<A>{
  public ResourceFieldSelectorFluentImpl() {
  }
  public ResourceFieldSelectorFluentImpl(io.fabric8.kubernetes.api.model.ResourceFieldSelector instance) {
    this.withContainerName(instance.getContainerName()); 
    this.withDivisor(instance.getDivisor()); 
    this.withResource(instance.getResource()); 
  }
  private java.lang.String containerName;
  private io.fabric8.kubernetes.api.model.QuantityBuilder divisor;
  private java.lang.String resource;
  public java.lang.String getContainerName() {
    return this.containerName;
  }
  public A withContainerName(java.lang.String containerName) {
    this.containerName=containerName; return (A) this;
  }
  public java.lang.Boolean hasContainerName() {
    return this.containerName != null;
  }
  
  /**
   * Method is deprecated. use withContainerName instead.
   */
  @java.lang.Deprecated
  public A withNewContainerName(java.lang.String arg0) {
    return (A)withContainerName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildDivisor instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Quantity getDivisor() {
    return this.divisor!=null?this.divisor.build():null;
  }
  public io.fabric8.kubernetes.api.model.Quantity buildDivisor() {
    return this.divisor!=null?this.divisor.build():null;
  }
  public A withDivisor(io.fabric8.kubernetes.api.model.Quantity divisor) {
    _visitables.get("divisor").remove(this.divisor);
    if (divisor!=null){ this.divisor= new io.fabric8.kubernetes.api.model.QuantityBuilder(divisor); _visitables.get("divisor").add(this.divisor);} return (A) this;
  }
  public java.lang.Boolean hasDivisor() {
    return this.divisor != null;
  }
  public A withNewDivisor(java.lang.String amount,java.lang.String format) {
    return (A)withDivisor(new Quantity(amount, format));
  }
  public A withNewDivisor(java.lang.String amount) {
    return (A)withDivisor(new Quantity(amount));
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> withNewDivisor() {
    return new io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluentImpl.DivisorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> withNewDivisorLike(io.fabric8.kubernetes.api.model.Quantity item) {
    return new io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluentImpl.DivisorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> editDivisor() {
    return withNewDivisorLike(getDivisor());
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> editOrNewDivisor() {
    return withNewDivisorLike(getDivisor() != null ? getDivisor(): new io.fabric8.kubernetes.api.model.QuantityBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> editOrNewDivisorLike(io.fabric8.kubernetes.api.model.Quantity item) {
    return withNewDivisorLike(getDivisor() != null ? getDivisor(): item);
  }
  public java.lang.String getResource() {
    return this.resource;
  }
  public A withResource(java.lang.String resource) {
    this.resource=resource; return (A) this;
  }
  public java.lang.Boolean hasResource() {
    return this.resource != null;
  }
  
  /**
   * Method is deprecated. use withResource instead.
   */
  @java.lang.Deprecated
  public A withNewResource(java.lang.String arg0) {
    return (A)withResource(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceFieldSelectorFluentImpl that = (ResourceFieldSelectorFluentImpl) o;
    if (containerName != null ? !containerName.equals(that.containerName) :that.containerName != null) return false;
    if (divisor != null ? !divisor.equals(that.divisor) :that.divisor != null) return false;
    if (resource != null ? !resource.equals(that.resource) :that.resource != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerName,  divisor,  resource,  super.hashCode());
  }
  
 /**
  * Quantity is fixed point representation of a number.
  * It provides convenient marshalling/unmarshalling in JSON or YAML,
  * in addition to String or getAmountInBytes accessors.
  */
public class DivisorNestedImpl<N> extends io.fabric8.kubernetes.api.model.QuantityFluentImpl<io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<N>> implements io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    DivisorNestedImpl(io.fabric8.kubernetes.api.model.Quantity item) {
      this.builder = new io.fabric8.kubernetes.api.model.QuantityBuilder(this, item);
    }
    DivisorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.QuantityBuilder(this);
    }
    io.fabric8.kubernetes.api.model.QuantityBuilder builder;
    public N and() {
      return (N) ResourceFieldSelectorFluentImpl.this.withDivisor(builder.build());
    }
    public N endDivisor() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/ResourceFieldSelectorFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ResourceFieldSelectorFluentImpl<A extends io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent<A>{
  public ResourceFieldSelectorFluentImpl() {
  }
  public ResourceFieldSelectorFluentImpl(io.fabric8.kubernetes.api.model.ResourceFieldSelector instance) {
    this.withContainerName(instance.getContainerName()); 
    this.withDivisor(instance.getDivisor()); 
    this.withResource(instance.getResource()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String containerName;
  private io.fabric8.kubernetes.api.model.QuantityBuilder divisor;
  private java.lang.String resource;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getContainerName() {
    return this.containerName;
  }
  public A withContainerName(java.lang.String containerName) {
    this.containerName=containerName; return (A) this;
  }
  public java.lang.Boolean hasContainerName() {
    return this.containerName != null;
  }
  
  /**
   * Method is deprecated. use withContainerName instead.
   */
  @java.lang.Deprecated
  public A withNewContainerName(java.lang.String arg0) {
    return (A)withContainerName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildDivisor instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Quantity getDivisor() {
    return this.divisor!=null?this.divisor.build():null;
  }
  public io.fabric8.kubernetes.api.model.Quantity buildDivisor() {
    return this.divisor!=null?this.divisor.build():null;
  }
  public A withDivisor(io.fabric8.kubernetes.api.model.Quantity divisor) {
    _visitables.get("divisor").remove(this.divisor);
    if (divisor!=null){ this.divisor= new io.fabric8.kubernetes.api.model.QuantityBuilder(divisor); _visitables.get("divisor").add(this.divisor);} return (A) this;
  }
  public java.lang.Boolean hasDivisor() {
    return this.divisor != null;
  }
  public A withNewDivisor(java.lang.String amount,java.lang.String format) {
    return (A)withDivisor(new Quantity(amount, format));
  }
  public A withNewDivisor(java.lang.String amount) {
    return (A)withDivisor(new Quantity(amount));
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> withNewDivisor() {
    return new io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluentImpl.DivisorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> withNewDivisorLike(io.fabric8.kubernetes.api.model.Quantity item) {
    return new io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluentImpl.DivisorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> editDivisor() {
    return withNewDivisorLike(getDivisor());
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> editOrNewDivisor() {
    return withNewDivisorLike(getDivisor() != null ? getDivisor(): new io.fabric8.kubernetes.api.model.QuantityBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<A> editOrNewDivisorLike(io.fabric8.kubernetes.api.model.Quantity item) {
    return withNewDivisorLike(getDivisor() != null ? getDivisor(): item);
  }
  public java.lang.String getResource() {
    return this.resource;
  }
  public A withResource(java.lang.String resource) {
    this.resource=resource; return (A) this;
  }
  public java.lang.Boolean hasResource() {
    return this.resource != null;
  }
  
  /**
   * Method is deprecated. use withResource instead.
   */
  @java.lang.Deprecated
  public A withNewResource(java.lang.String arg0) {
    return (A)withResource(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceFieldSelectorFluentImpl that = (ResourceFieldSelectorFluentImpl) o;
    if (containerName != null ? !containerName.equals(that.containerName) :that.containerName != null) return false;
    if (divisor != null ? !divisor.equals(that.divisor) :that.divisor != null) return false;
    if (resource != null ? !resource.equals(that.resource) :that.resource != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerName,  divisor,  resource,  additionalProperties,  super.hashCode());
  }
  
 /**
  * Quantity is fixed point representation of a number.
  * It provides convenient marshalling/unmarshalling in JSON or YAML,
  * in addition to String or getAmountInBytes accessors.
  */
public class DivisorNestedImpl<N> extends io.fabric8.kubernetes.api.model.QuantityFluentImpl<io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<N>> implements io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluent.DivisorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    DivisorNestedImpl(io.fabric8.kubernetes.api.model.Quantity item) {
      this.builder = new io.fabric8.kubernetes.api.model.QuantityBuilder(this, item);
    }
    DivisorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.QuantityBuilder(this);
    }
    io.fabric8.kubernetes.api.model.QuantityBuilder builder;
    public N and() {
      return (N) ResourceFieldSelectorFluentImpl.this.withDivisor(builder.build());
    }
    public N endDivisor() {
      return and();
    }
    
  }
  
}
